@@ -1,8 +1,9 @@
 import asyncio
 import time
 import itertools
+import inspect
 from asyncio import Queue
-from typing import Any, Iterable, Optional, Callable, AsyncIterator, AsyncGenerator, Union, Awaitable
+from typing import Any, Iterable, Optional, Callable, AsyncIterator, AsyncGenerator, Union, Awaitable, Protocol
 from dataclasses import dataclass, field
 import heapq
 
@@ -11,6 +12,22 @@ from .interface import RequestResult
 from .progress import ProgressTracker, ProgressBarConfig
 
 
+# 添加函数协议定义
+class TaskFunction(Protocol):
+    """任务函数协议"""
+    async def __call__(self, *args, **kwargs) -> Any: ...
+
+
+@dataclass 
+class TaskContext:
+    """任务执行上下文，包含所有可能需要的信息"""
+    task_id: int
+    data: Any
+    meta: Optional[dict] = None
+    retry_count: int = 0
+    executor_kwargs: Optional[dict] = None
+
+
 @dataclass
 class TaskItem:
     """任务项，支持优先级"""
@@ -74,14 +91,32 @@ class ConcurrentExecutor:
     - 流式结果返回
     - 优先级调度
     - 自定义错误处理
+    - 智能函数调用模式
+    
+    支持的执行方法：
+    - execute_batch: 智能批量执行，自动检测函数签名
+    - execute_batch_with_adapter: 使用适配器的批量执行
+    - execute_batch_with_context: 上下文模式的批量执行
+    - execute_batch_with_factory: 函数工厂模式的批量执行
+    - execute_priority_batch: 按优先级的批量执行
+    - aiter_execute_batch: 流式批量执行
+    - execute_batch_sync: 同步版本的批量执行
     
     Example
     -------
     
-    # 定义一个异步函数
-    async def my_async_task(data, meta=None):
-        await asyncio.sleep(0.1)  # 模拟异步操作
+    # 方式1: 简单函数 - 仅接收数据
+    async def simple_task(data):
+        await asyncio.sleep(0.1)
         return f"processed: {data}"
+        
+    # 方式2: 上下文函数 - 接收完整上下文
+    async def context_task(context: TaskContext):
+        return f"task_{context.task_id}: {context.data} (retry: {context.retry_count})"
+        
+    # 方式3: 通用函数 - 接受任意参数
+    async def flexible_task(item, **options):
+        return f"processed {item} with {options}"
     
     # 创建执行器
     executor = ConcurrentExecutor(
@@ -90,26 +125,29 @@ class ConcurrentExecutor:
         retry_times=3
     )
     
-    # 准备任务数据
-    tasks_data = [f"task_{i}" for i in range(100)]
-    
-    # 批量执行
-    results, progress = await executor.execute_batch(
-        async_func=my_async_task,
-        tasks_data=tasks_data,
-        show_progress=True
+    # 智能批量执行 - 自动检测函数签名适配调用方式
+    results, _ = await executor.execute_batch(
+        async_func=simple_task,         # 简单函数
+        tasks_data=["task1", "task2", "task3"]
     )
     
-    # 优先级执行
-    priority_tasks = [
-        TaskItem(priority=1, task_id=0, data="高优先级任务"),
-        TaskItem(priority=3, task_id=1, data="低优先级任务"),
-        TaskItem(priority=2, task_id=2, data="中优先级任务"),
-    ]
+    results, _ = await executor.execute_batch(
+        async_func=flexible_task,       # 通用函数
+        tasks_data=["item1", "item2"],
+        executor_kwargs={"user_id": 123, "mode": "fast"}
+    )
     
-    results, _ = await executor.execute_priority_batch(
-        async_func=my_async_task,
-        priority_tasks=priority_tasks
+    # 使用任务适配器（适配复杂函数签名）
+    results, _ = await executor.execute_batch_with_adapter(
+        async_func=complex_function,
+        tasks_data=complex_data,
+        task_adapter=my_adapter_function
+    )
+    
+    # 使用上下文模式（获取完整执行信息）
+    results, _ = await executor.execute_batch_with_context(
+        async_func=context_task,
+        tasks_data=["data1", "data2"]
     )
     """
 
@@ -128,17 +166,71 @@ class ConcurrentExecutor:
         self.retry_delay = retry_delay
         self.error_handler = error_handler  # 自定义错误处理函数
 
+    def _inspect_function_signature(self, func: Callable) -> dict:
+        """检查函数签名，返回参数信息"""
+        sig = inspect.signature(func)
+        params = sig.parameters
+        
+        # 更强大的TaskContext检测
+        has_context_param = False
+        for param in params.values():
+            # 检查类型注解
+            if param.annotation == TaskContext:
+                has_context_param = True
+                break
+            # 检查字符串形式的注解
+            if isinstance(param.annotation, str) and 'TaskContext' in param.annotation:
+                has_context_param = True
+                break
+            # 检查参数名称（作为备选检测方式）
+            if param.name == 'context' and len(params) == 1:
+                has_context_param = True
+                break
+        
+        return {
+            'param_names': list(params.keys()),
+            'has_context_param': has_context_param,
+            'accepts_var_kwargs': any(p.kind == p.VAR_KEYWORD for p in params.values()),
+            'param_count': len([p for p in params.values() if p.kind in (p.POSITIONAL_ONLY, p.POSITIONAL_OR_KEYWORD)])
+        }
+
+    async def _call_function_intelligently(
+            self,
+            func: Callable,
+            task_context: TaskContext,
+            executor_kwargs: Optional[dict] = None
+    ) -> Any:
+        """智能调用函数，根据函数签名自动适配参数"""
+        sig_info = self._inspect_function_signature(func)
+        executor_kwargs = executor_kwargs or {}
+        
+        # 方式1: 如果函数接受TaskContext类型参数
+        if sig_info['has_context_param']:
+            # 上下文函数不接受额外的关键字参数，所有信息都在TaskContext中
+            return await func(task_context)
+        
+        # 方式2: 只接受data的简单函数
+        elif sig_info['param_count'] == 1 and not sig_info['accepts_var_kwargs']:
+            return await func(task_context.data)
+        
+        # 方式3: 接受任意参数的通用函数
+        else:
+            return await func(task_context.data, **executor_kwargs)
+
     async def _execute_single_task(
             self,
             async_func: Callable[..., Awaitable[Any]],
             task_data: Any,
             task_id: int,
             meta: Optional[dict] = None,
+            executor_kwargs: Optional[dict] = None,
+            task_adapter: Optional[Callable] = None,
             **kwargs
     ) -> ExecutionResult:
         """执行单个异步任务"""
         retry_count = 0
         last_error = None
+        executor_kwargs = {**(executor_kwargs or {}), **kwargs}
         
         async with self._semaphore:
             while retry_count <= self.retry_times:
@@ -146,7 +238,28 @@ class ConcurrentExecutor:
                     await self._rate_limiter.acquire()
                     
                     start_time = time.time()
-                    result = await async_func(task_data, meta=meta, **kwargs)
+                    
+                    # 创建任务上下文
+                    task_context = TaskContext(
+                        task_id=task_id,
+                        data=task_data,
+                        meta=meta,
+                        retry_count=retry_count,
+                        executor_kwargs=executor_kwargs
+                    )
+                    
+                    # 使用适配器或智能调用
+                    if task_adapter:
+                        args, kwargs_from_adapter = task_adapter(task_data, task_context)
+                        if isinstance(args, (list, tuple)):
+                            result = await async_func(*args, **{**executor_kwargs, **kwargs_from_adapter})
+                        else:
+                            result = await async_func(args, **{**executor_kwargs, **kwargs_from_adapter})
+                    else:
+                        result = await self._call_function_intelligently(
+                            async_func, task_context, executor_kwargs
+                        )
+                    
                     latency = time.time() - start_time
 
                     return ExecutionResult(
@@ -504,4 +617,164 @@ class ConcurrentExecutor:
         Args:
             handler: 错误处理函数，签名为 (error, task_data, retry_count) -> should_retry
         """
-        self.error_handler = handler 
\ No newline at end of file
+        self.error_handler = handler 
+
+    # === 新增的更灵活的执行方法 ===
+    
+    async def execute_batch_with_adapter(
+            self,
+            async_func: Callable[..., Awaitable[Any]],
+            tasks_data: Iterable[Any],
+            task_adapter: Callable[[Any, TaskContext], tuple[Any, dict]],
+            executor_kwargs: Optional[dict] = None,
+            total_tasks: Optional[int] = None,
+            show_progress: bool = True,
+            **kwargs
+    ) -> tuple[list[ExecutionResult], Optional[ProgressTracker]]:
+        """
+        使用任务适配器的批量执行
+        
+        Args:
+            async_func: 要执行的异步函数
+            tasks_data: 任务数据列表
+            task_adapter: 任务适配器函数，签名为 (data, context) -> (args, kwargs)
+                         返回值应为 (位置参数, 关键字参数) 的元组
+            executor_kwargs: 传递给所有任务的公共参数
+            total_tasks: 总任务数量
+            show_progress: 是否显示进度
+            **kwargs: 其他参数
+            
+        Returns:
+            (结果列表, 进度跟踪器)
+            
+        Example:
+            # 定义适配器函数
+            def my_adapter(data, context):
+                # 返回位置参数和关键字参数
+                return (data['item'],), {'user_id': data['user_id'], 'batch_id': context.task_id}
+            
+            # 执行
+            results, _ = await executor.execute_batch_with_adapter(
+                async_func=my_custom_function,
+                tasks_data=[{'item': 'a', 'user_id': 1}, {'item': 'b', 'user_id': 2}],
+                task_adapter=my_adapter,
+                executor_kwargs={'mode': 'fast'}
+            )
+        """
+        progress = None
+        
+        if total_tasks is None and show_progress:
+            tasks_data, data_for_counting = itertools.tee(tasks_data)
+            total_tasks = sum(1 for _ in data_for_counting)
+
+        if show_progress and total_tasks is not None:
+            progress = ProgressTracker(
+                total_tasks,
+                concurrency=self._concurrency_limit,
+                config=ProgressBarConfig()
+            )
+
+        results = []
+        async for result in self._process_with_concurrency_window(
+                async_func=async_func,
+                tasks_data=tasks_data,
+                progress=progress,
+                executor_kwargs=executor_kwargs,
+                task_adapter=task_adapter,
+                **kwargs
+        ):
+            results.extend(result.completed_tasks)
+
+        # 按任务ID排序
+        results = sorted(results, key=lambda x: x.task_id)
+        return results, progress
+
+    async def execute_batch_with_context(
+            self,
+            async_func: Callable[[TaskContext], Awaitable[Any]],
+            tasks_data: Iterable[Any],
+            executor_kwargs: Optional[dict] = None,
+            total_tasks: Optional[int] = None,
+            show_progress: bool = True,
+            **kwargs
+    ) -> tuple[list[ExecutionResult], Optional[ProgressTracker]]:
+        """
+        使用上下文模式的批量执行，函数直接接收TaskContext对象
+        
+        Args:
+            async_func: 要执行的异步函数，签名应为 async def func(context: TaskContext) -> Any
+            tasks_data: 任务数据列表  
+            executor_kwargs: 传递给TaskContext的额外参数
+            total_tasks: 总任务数量
+            show_progress: 是否显示进度
+            **kwargs: 其他参数
+            
+        Returns:
+            (结果列表, 进度跟踪器)
+            
+        Example:
+            async def context_task(context: TaskContext):
+                print(f"处理任务 {context.task_id}: {context.data}")
+                print(f"重试次数: {context.retry_count}")
+                print(f"额外参数: {context.executor_kwargs}")
+                return f"结果: {context.data}"
+            
+            results, _ = await executor.execute_batch_with_context(
+                async_func=context_task,
+                tasks_data=["data1", "data2", "data3"],
+                executor_kwargs={'user_id': 123}
+            )
+        """
+        return await self.execute_batch(
+            async_func=async_func,
+            tasks_data=tasks_data,
+            total_tasks=total_tasks,
+            show_progress=show_progress,
+            executor_kwargs=executor_kwargs,
+            **kwargs
+        )
+
+    async def execute_batch_with_factory(
+            self,
+            func_factory: Callable[[TaskContext], Callable[..., Awaitable[Any]]],
+            tasks_data: Iterable[Any],
+            total_tasks: Optional[int] = None,
+            show_progress: bool = True,
+            **kwargs
+    ) -> tuple[list[ExecutionResult], Optional[ProgressTracker]]:
+        """
+        使用函数工厂的批量执行，可以为每个任务动态创建不同的执行函数
+        
+        Args:
+            func_factory: 函数工厂，根据上下文返回要执行的函数
+            tasks_data: 任务数据列表
+            total_tasks: 总任务数量
+            show_progress: 是否显示进度
+            **kwargs: 其他参数
+            
+        Returns:
+            (结果列表, 进度跟踪器)
+            
+        Example:
+            def task_factory(context: TaskContext):
+                if context.task_id % 2 == 0:
+                    return slow_processor
+                else:
+                    return fast_processor
+                    
+            results, _ = await executor.execute_batch_with_factory(
+                func_factory=task_factory,
+                tasks_data=["data1", "data2", "data3"]
+            )
+        """
+        async def factory_wrapper(context: TaskContext):
+            actual_func = func_factory(context)
+            return await actual_func(context.data)
+            
+        return await self.execute_batch_with_context(
+            async_func=factory_wrapper,
+            tasks_data=tasks_data,
+            total_tasks=total_tasks,
+            show_progress=show_progress,
+            **kwargs
+        ) 
\ No newline at end of file
