@@ -3,6 +3,7 @@ import pickle
 from typing import Union, List, Dict
 import shutil
 import os
+import yaml
 
 
 def rm(*file_pattern: str, rel=False):
@@ -49,11 +50,28 @@ def json_dump(data: Union[List, Dict], filepath: str, rel=False, indent_2=False,
         f.write(orjson.dumps(data, option=orjson_option))
 
 
-def yaml_dump(filepath, data, rel_path=False, mode='w'):
-    import yaml
+# 自定义多行字符串的显示方式，去除行尾空格
+def str_presenter(dumper, data):
+    """
+    """
+    # 去除每一行的行尾空格
+    data = "\n".join([line.rstrip() for line in data.splitlines()])
+    if "\n" in data:
+        return dumper.represent_scalar("tag:yaml.org,2002:str", data, style="|")
+    return dumper.represent_scalar("tag:yaml.org,2002:str", data)
+
+
+# 添加自定义表示器
+yaml.add_representer(str, str_presenter)
+
+
+def yaml_dump(filepath, data, rel_path=False, mode="w"):
+    """Yaml dump"""
     abs_path = rel_to_abs(filepath, parents=1) if rel_path else filepath
+
     with open(abs_path, mode=mode, encoding="utf-8") as fw:
-        yaml.dump(data, fw, allow_unicode=True, indent=4)
+        yaml.dump(data, fw, allow_unicode=True, indent=4, sort_keys=False, default_flow_style=False)
+
 
 def yaml_load(filepath, rel_path=False, mode='r'):
     import yaml
@@ -98,3 +116,12 @@ def join_files(input_prefix, input_dir, output_path=None):
         for part in parts:
             with open(os.path.join(input_dir, part), "rb") as part_file:
                 output_file.write(part_file.read())
+
+
+def find_free_port():
+    """Find a free port to use for the server."""
+    import socket
+
+    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+        s.bind(('', 0))
+        return s.getsockname()[1]
